@@ -75,6 +75,12 @@ int main(int argc, char **argv)
      */
     Q_INIT_RESOURCE(kate);
 
+    /**
+     * enable high dpi support
+     */
+    QCoreApplication::setAttribute(Qt::AA_UseHighDpiPixmaps, true);
+    QCoreApplication::setAttribute(Qt::AA_EnableHighDpiScaling, true);
+
     /**
      * Create application first
      */
@@ -89,11 +95,6 @@ int main(int argc, char **argv)
      */
     app.setApplicationName(QStringLiteral("kate"));
 
-    /**
-     * enable high dpi support
-     */
-    app.setAttribute(Qt::AA_UseHighDpiPixmaps, true);
-
     /**
      * Enable crash handling through KCrash.
      */
