@@ -63,6 +63,13 @@ extern "C" Q_DECL_EXPORT int main(int argc, char **argv)
         }
     }
 #endif
+
+    /**
+     * enable high dpi support
+     */
+    QCoreApplication::setAttribute(Qt::AA_UseHighDpiPixmaps, true);
+    QCoreApplication::setAttribute(Qt::AA_EnableHighDpiScaling, true);
+
     /**
      * Create application first
      * Enforce application name even if the executable is renamed
@@ -70,11 +77,6 @@ extern "C" Q_DECL_EXPORT int main(int argc, char **argv)
     QApplication app(argc, argv);
     app.setApplicationName(QStringLiteral("kwrite"));
 
-    /**
-     * enable high dpi support
-     */
-    app.setAttribute(Qt::AA_UseHighDpiPixmaps, true);
-
     /**
      * Enable crash handling through KCrash.
      */
